@@ -8,18 +8,14 @@
 @License :   Apache License 2.0
 """
 
-__all__ = [
-    "build_selector",
-    "RandomAsyncSelector",
-    "RandomSelector",
-]
+__all__ = ["build_selector", "RandomFedAsyncSelector", "RandomSelector", "selector_factory"]
 
-from .random_async_selector import RandomAsyncSelector
+from .random_fedasync_selector import RandomFedAsyncSelector
 from .random_selector import RandomSelector
 
 selector_factory = {
     'random': RandomSelector,
-    'random_async': RandomAsyncSelector
+    'random_fedasync': RandomFedAsyncSelector,
 }
 
 
