@@ -18,5 +18,8 @@ class RandomSelector(BaseSelector):
         self.args = args
 
     def select(self, client_list: list) -> list:
-        selected_clients = np.random.choice(client_list, int(self.args.num_clients * self.args.select_ratio))
+        selected_clients = np.random.choice(client_list,
+                                            int(self.args.num_clients *
+                                                self.args.select_ratio),
+                                            replace=False)
         return selected_clients
